Class: Google::Apis::ServicecontrolV2::CheckResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb

Overview

Response message for the Check method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CheckResponse

Returns a new instance of CheckResponse.



635
636
637
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 635

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dynamic_metadataHash<String,Object>

Optional response metadata that will be emitted as dynamic metadata to be consumed by the caller of ServiceController. For compatibility with the ext_authz interface. Corresponds to the JSON property dynamicMetadata

Returns:

  • (Hash<String,Object>)


618
619
620
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 618

def 
  @dynamic_metadata
end

#headersHash<String,String>

Returns a set of request contexts generated from the CheckRequest. Corresponds to the JSON property headers

Returns:

  • (Hash<String,String>)


623
624
625
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 623

def headers
  @headers
end

#statusGoogle::Apis::ServicecontrolV2::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



633
634
635
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 633

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



640
641
642
643
644
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 640

def update!(**args)
  @dynamic_metadata = args[:dynamic_metadata] if args.key?(:dynamic_metadata)
  @headers = args[:headers] if args.key?(:headers)
  @status = args[:status] if args.key?(:status)
end