Class: Google::Apis::ServicecontrolV2::Peer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb

Overview

This message defines attributes for a node that handles a network request. The node can be either a service or an application that sends, forwards, or receives the request. Service peers should fill in principal and labels as appropriate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Peer

Returns a new instance of Peer.



790
791
792
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 790

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ipString

The IP address of the peer. Corresponds to the JSON property ip

Returns:

  • (String)


764
765
766
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 764

def ip
  @ip
end

#labelsHash<String,String>

The labels associated with the peer. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


769
770
771
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 769

def labels
  @labels
end

#portFixnum

The network port of the peer. Corresponds to the JSON property port

Returns:

  • (Fixnum)


774
775
776
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 774

def port
  @port
end

#principalString

The identity of this peer. Similar to Request.auth.principal, but relative to the peer instead of the request. For example, the identity associated with a load balancer that forwarded the request. Corresponds to the JSON property principal

Returns:

  • (String)


781
782
783
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 781

def principal
  @principal
end

#region_codeString

The CLDR country/region code associated with the above IP address. If the IP address is private, the region_code should reflect the physical location where this peer is running. Corresponds to the JSON property regionCode

Returns:

  • (String)


788
789
790
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 788

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



795
796
797
798
799
800
801
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 795

def update!(**args)
  @ip = args[:ip] if args.key?(:ip)
  @labels = args[:labels] if args.key?(:labels)
  @port = args[:port] if args.key?(:port)
  @principal = args[:principal] if args.key?(:principal)
  @region_code = args[:region_code] if args.key?(:region_code)
end