Class: Google::Apis::ServicecontrolV2::RequestMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV2::RequestMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb
Overview
Metadata about the request.
Instance Attribute Summary collapse
-
#caller_ip ⇒ String
The IP address of the caller.
-
#caller_network ⇒ String
The network of the caller.
-
#caller_supplied_user_agent ⇒ String
The user agent of the caller.
-
#destination_attributes ⇒ Google::Apis::ServicecontrolV2::Peer
This message defines attributes for a node that handles a network request.
-
#request_attributes ⇒ Google::Apis::ServicecontrolV2::Request
This message defines attributes for an HTTP request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RequestMetadata
constructor
A new instance of RequestMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RequestMetadata
Returns a new instance of RequestMetadata.
1089 1090 1091 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1089 def initialize(**args) update!(**args) end |
Instance Attribute Details
#caller_ip ⇒ String
The IP address of the caller. For a caller from the internet, this will be the
public IPv4 or IPv6 address. For calls made from inside Google's internal
production network from one GCP service to another, caller_ip will be
redacted to "private". For a caller from a Compute Engine VM with a external
IP address, caller_ip will be the VM's external IP address. For a caller
from a Compute Engine VM without a external IP address, if the VM is in the
same organization (or project) as the accessed resource, caller_ip will be
the VM's internal IPv4 address, otherwise caller_ip will be redacted to "gce-
internal-ip". See https://cloud.google.com/compute/docs/vpc/ for more
information.
Corresponds to the JSON property callerIp
1052 1053 1054 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1052 def caller_ip @caller_ip end |
#caller_network ⇒ String
The network of the caller. Set only if the network host project is part of the
same GCP organization (or project) as the accessed resource. See https://cloud.
google.com/compute/docs/vpc/ for more information. This is a scheme-less URI
full resource name. For example: "//compute.googleapis.com/projects/PROJECT_ID/
global/networks/NETWORK_ID"
Corresponds to the JSON property callerNetwork
1061 1062 1063 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1061 def caller_network @caller_network end |
#caller_supplied_user_agent ⇒ String
The user agent of the caller. This information is not authenticated and should
be treated accordingly. For example: + google-api-python-client/1.4.0: The
request was made by the Google API client for Python. + Cloud SDK Command
Line Tool apitools-client/1.0 gcloud/0.9.62: The request was made by the
Google Cloud SDK CLI (gcloud). + AppEngine-Google; (+http://code.google.com/
appengine; appid: s~my-project: The request was made from the my-project
App Engine app.
Corresponds to the JSON property callerSuppliedUserAgent
1072 1073 1074 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1072 def caller_supplied_user_agent @caller_supplied_user_agent end |
#destination_attributes ⇒ Google::Apis::ServicecontrolV2::Peer
This message defines attributes for a node that handles a network request. The
node can be either a service or an application that sends, forwards, or
receives the request. Service peers should fill in principal and labels as
appropriate.
Corresponds to the JSON property destinationAttributes
1080 1081 1082 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1080 def destination_attributes @destination_attributes end |
#request_attributes ⇒ Google::Apis::ServicecontrolV2::Request
This message defines attributes for an HTTP request. If the actual request is
not an HTTP request, the runtime system should try to map the actual request
to an equivalent HTTP request.
Corresponds to the JSON property requestAttributes
1087 1088 1089 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1087 def request_attributes @request_attributes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1094 1095 1096 1097 1098 1099 1100 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1094 def update!(**args) @caller_ip = args[:caller_ip] if args.key?(:caller_ip) @caller_network = args[:caller_network] if args.key?(:caller_network) @caller_supplied_user_agent = args[:caller_supplied_user_agent] if args.key?(:caller_supplied_user_agent) @destination_attributes = args[:destination_attributes] if args.key?(:destination_attributes) @request_attributes = args[:request_attributes] if args.key?(:request_attributes) end |