Class: Google::Apis::ServicecontrolV2::ServiceControlService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ServicecontrolV2::ServiceControlService
- Defined in:
- lib/google/apis/servicecontrol_v2/service.rb
Overview
Service Control API
Provides admission control and telemetry reporting for services integrated with Service Infrastructure.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://servicecontrol.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#check_service(service_name, check_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicecontrolV2::CheckResponse
This method provides admission control for services that are integrated with Service Infrastructure.
-
#initialize ⇒ ServiceControlService
constructor
A new instance of ServiceControlService.
-
#report_service(service_name, report_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicecontrolV2::ReportResponse
This method provides telemetry reporting for services that are integrated with Service Infrastructure.
Constructor Details
#initialize ⇒ ServiceControlService
Returns a new instance of ServiceControlService.
48 49 50 51 52 53 |
# File 'lib/google/apis/servicecontrol_v2/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-servicecontrol_v2', client_version: Google::Apis::ServicecontrolV2::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/servicecontrol_v2/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/servicecontrol_v2/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#check_service(service_name, check_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicecontrolV2::CheckResponse
This method provides admission control for services that are integrated with
Service Infrastructure. It
checks whether an operation should be allowed based on the service
configuration and relevant policies. It must be called before the operation is
executed. For more information, see Admission Control. NOTE: The admission
control has an expected policy propagation delay of 60s. The caller must
not depend on the most recent policy changes. NOTE: The admission control has
a hard limit of 1 referenced resources per call. If an operation refers to
more than 1 resources, the caller must call the Check method multiple times.
This method requires the servicemanagement.services.check permission on the
specified service. For more information, see Service Control API Access
Control.
92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/google/apis/servicecontrol_v2/service.rb', line 92 def check_service(service_name, check_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/services/{serviceName}:check', ) command.request_representation = Google::Apis::ServicecontrolV2::CheckRequest::Representation command.request_object = check_request_object command.response_representation = Google::Apis::ServicecontrolV2::CheckResponse::Representation command.response_class = Google::Apis::ServicecontrolV2::CheckResponse command.params['serviceName'] = service_name unless service_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#report_service(service_name, report_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicecontrolV2::ReportResponse
This method provides telemetry reporting for services that are integrated with
Service Infrastructure. It
reports a list of operations that have occurred on a service. It must be
called after the operations have been executed. For more information, see
Telemetry Reporting. NOTE: The telemetry reporting has a hard limit of 100
operations and 1MB per Report call. This method requires the
servicemanagement.services.report permission on the specified service. For
more information, see Service Control API Access Control.
137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/google/apis/servicecontrol_v2/service.rb', line 137 def report_service(service_name, report_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/services/{serviceName}:report', ) command.request_representation = Google::Apis::ServicecontrolV2::ReportRequest::Representation command.request_object = report_request_object command.response_representation = Google::Apis::ServicecontrolV2::ReportResponse::Representation command.response_class = Google::Apis::ServicecontrolV2::ReportResponse command.params['serviceName'] = service_name unless service_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |