Class: Google::Apis::ServicecontrolV2::V2HttpRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV2::V2HttpRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb
Overview
A common proto for logging HTTP requests. Only contains semantics defined by the HTTP specification. Product-specific logging information MUST be defined in a separate message.
Instance Attribute Summary collapse
-
#cache_fill_bytes ⇒ Fixnum
The number of HTTP response bytes inserted into cache.
-
#cache_hit ⇒ Boolean
(also: #cache_hit?)
Whether or not an entity was served from cache (with or without validation).
-
#cache_lookup ⇒ Boolean
(also: #cache_lookup?)
Whether or not a cache lookup was attempted.
-
#cache_validated_with_origin_server ⇒ Boolean
(also: #cache_validated_with_origin_server?)
Whether or not the response was validated with the origin server before being served from cache.
-
#latency ⇒ String
The request processing latency on the server, from the time the request was received until the response was sent.
-
#protocol ⇒ String
Protocol used for the request.
-
#referer ⇒ String
The referer URL of the request, as defined in HTTP/1.1 Header Field Definitions.
-
#remote_ip ⇒ String
The IP address (IPv4 or IPv6) of the client that issued the HTTP request.
-
#request_method ⇒ String
The request method.
-
#request_size ⇒ Fixnum
The size of the HTTP request message in bytes, including the request headers and the request body.
-
#request_url ⇒ String
The scheme (http, https), the host name, the path, and the query portion of the URL that was requested.
-
#response_size ⇒ Fixnum
The size of the HTTP response message sent back to the client, in bytes, including the response headers and the response body.
-
#server_ip ⇒ String
The IP address (IPv4 or IPv6) of the origin server that the request was sent to.
-
#status ⇒ Fixnum
The response code indicating the status of the response.
-
#user_agent ⇒ String
The user agent sent by the client.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V2HttpRequest
constructor
A new instance of V2HttpRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V2HttpRequest
Returns a new instance of V2HttpRequest.
1634 1635 1636 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1634 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_fill_bytes ⇒ Fixnum
The number of HTTP response bytes inserted into cache. Set only when a cache
fill was attempted.
Corresponds to the JSON property cacheFillBytes
1549 1550 1551 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1549 def cache_fill_bytes @cache_fill_bytes end |
#cache_hit ⇒ Boolean Also known as: cache_hit?
Whether or not an entity was served from cache (with or without validation).
Corresponds to the JSON property cacheHit
1554 1555 1556 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1554 def cache_hit @cache_hit end |
#cache_lookup ⇒ Boolean Also known as: cache_lookup?
Whether or not a cache lookup was attempted.
Corresponds to the JSON property cacheLookup
1560 1561 1562 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1560 def cache_lookup @cache_lookup end |
#cache_validated_with_origin_server ⇒ Boolean Also known as: cache_validated_with_origin_server?
Whether or not the response was validated with the origin server before being
served from cache. This field is only meaningful if cache_hit is True.
Corresponds to the JSON property cacheValidatedWithOriginServer
1567 1568 1569 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1567 def cache_validated_with_origin_server @cache_validated_with_origin_server end |
#latency ⇒ String
The request processing latency on the server, from the time the request was
received until the response was sent.
Corresponds to the JSON property latency
1574 1575 1576 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1574 def latency @latency end |
#protocol ⇒ String
Protocol used for the request. Examples: "HTTP/1.1", "HTTP/2", "websocket"
Corresponds to the JSON property protocol
1579 1580 1581 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1579 def protocol @protocol end |
#referer ⇒ String
The referer URL of the request, as defined in HTTP/1.1 Header Field
Definitions.
Corresponds to the JSON property referer
1585 1586 1587 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1585 def referer @referer end |
#remote_ip ⇒ String
The IP address (IPv4 or IPv6) of the client that issued the HTTP request.
Examples: "192.168.1.1", "FE80::0202:B3FF:FE1E:8329".
Corresponds to the JSON property remoteIp
1591 1592 1593 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1591 def remote_ip @remote_ip end |
#request_method ⇒ String
The request method. Examples: "GET", "HEAD", "PUT", "POST".
Corresponds to the JSON property requestMethod
1596 1597 1598 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1596 def request_method @request_method end |
#request_size ⇒ Fixnum
The size of the HTTP request message in bytes, including the request headers
and the request body.
Corresponds to the JSON property requestSize
1602 1603 1604 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1602 def request_size @request_size end |
#request_url ⇒ String
The scheme (http, https), the host name, the path, and the query portion of
the URL that was requested. Example: "http://example.com/some/info?color=red"
.
Corresponds to the JSON property requestUrl
1609 1610 1611 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1609 def request_url @request_url end |
#response_size ⇒ Fixnum
The size of the HTTP response message sent back to the client, in bytes,
including the response headers and the response body.
Corresponds to the JSON property responseSize
1615 1616 1617 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1615 def response_size @response_size end |
#server_ip ⇒ String
The IP address (IPv4 or IPv6) of the origin server that the request was sent
to.
Corresponds to the JSON property serverIp
1621 1622 1623 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1621 def server_ip @server_ip end |
#status ⇒ Fixnum
The response code indicating the status of the response. Examples: 200, 404.
Corresponds to the JSON property status
1626 1627 1628 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1626 def status @status end |
#user_agent ⇒ String
The user agent sent by the client. Example: "Mozilla/4.0 (compatible; MSIE 6.
0; Windows 98; Q312461; .NET CLR 1.0.3705)".
Corresponds to the JSON property userAgent
1632 1633 1634 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1632 def user_agent @user_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1639 def update!(**args) @cache_fill_bytes = args[:cache_fill_bytes] if args.key?(:cache_fill_bytes) @cache_hit = args[:cache_hit] if args.key?(:cache_hit) @cache_lookup = args[:cache_lookup] if args.key?(:cache_lookup) @cache_validated_with_origin_server = args[:cache_validated_with_origin_server] if args.key?(:cache_validated_with_origin_server) @latency = args[:latency] if args.key?(:latency) @protocol = args[:protocol] if args.key?(:protocol) @referer = args[:referer] if args.key?(:referer) @remote_ip = args[:remote_ip] if args.key?(:remote_ip) @request_method = args[:request_method] if args.key?(:request_method) @request_size = args[:request_size] if args.key?(:request_size) @request_url = args[:request_url] if args.key?(:request_url) @response_size = args[:response_size] if args.key?(:response_size) @server_ip = args[:server_ip] if args.key?(:server_ip) @status = args[:status] if args.key?(:status) @user_agent = args[:user_agent] if args.key?(:user_agent) end |