Class: Google::Apis::ServicecontrolV2::V2LogEntryOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb

Overview

Additional information about a potentially long-running operation with which a log entry is associated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V2LogEntryOperation

Returns a new instance of V2LogEntryOperation.



1793
1794
1795
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firstBoolean Also known as: first?

Optional. Set this to True if this is the first log entry in the operation. Corresponds to the JSON property first

Returns:

  • (Boolean)


1771
1772
1773
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1771

def first
  @first
end

#idString

Optional. An arbitrary operation identifier. Log entries with the same identifier are assumed to be part of the same operation. Corresponds to the JSON property id

Returns:

  • (String)


1778
1779
1780
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1778

def id
  @id
end

#lastBoolean Also known as: last?

Optional. Set this to True if this is the last log entry in the operation. Corresponds to the JSON property last

Returns:

  • (Boolean)


1783
1784
1785
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1783

def last
  @last
end

#producerString

Optional. An arbitrary producer identifier. The combination of id and producer must be globally unique. Examples for producer: "MyDivision. MyBigCompany.com", "github.com/MyProject/MyApplication". Corresponds to the JSON property producer

Returns:

  • (String)


1791
1792
1793
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1791

def producer
  @producer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1798
1799
1800
1801
1802
1803
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1798

def update!(**args)
  @first = args[:first] if args.key?(:first)
  @id = args[:id] if args.key?(:id)
  @last = args[:last] if args.key?(:last)
  @producer = args[:producer] if args.key?(:producer)
end