Class: Google::Apis::ServicecontrolV2::CheckRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV2::CheckRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb
Overview
Request message for the Check method.
Instance Attribute Summary collapse
-
#attributes ⇒ Google::Apis::ServicecontrolV2::AttributeContext
This message defines the standard attribute vocabulary for Google APIs.
-
#flags ⇒ String
Optional.
-
#resources ⇒ Array<Google::Apis::ServicecontrolV2::ResourceInfo>
Describes the resources and the policies applied to each resource.
-
#service_config_id ⇒ String
Specifies the version of the service configuration that should be used to process the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckRequest
constructor
A new instance of CheckRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckRequest
Returns a new instance of CheckRequest.
541 542 543 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 541 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Google::Apis::ServicecontrolV2::AttributeContext
This message defines the standard attribute vocabulary for Google APIs. An
attribute is a piece of metadata that describes an activity on a network
service. For example, the size of an HTTP request, or the status code of an
HTTP response. Each attribute has a type and a name, which is logically
defined as a proto message field in AttributeContext. The field type becomes
the attribute type, and the field path becomes the attribute name. For example,
the attribute source.ip maps to field AttributeContext.source.ip. This
message definition is guaranteed not to have any wire breaking change. So you
can use it directly for passing attributes across different systems. NOTE:
Different system may generate different subset of attributes. Please verify
the system specification before relying on an attribute generated a system.
Corresponds to the JSON property attributes
522 523 524 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 522 def attributes @attributes end |
#flags ⇒ String
Optional. Contains a comma-separated list of flags.
Corresponds to the JSON property flags
527 528 529 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 527 def flags @flags end |
#resources ⇒ Array<Google::Apis::ServicecontrolV2::ResourceInfo>
Describes the resources and the policies applied to each resource.
Corresponds to the JSON property resources
532 533 534 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 532 def resources @resources end |
#service_config_id ⇒ String
Specifies the version of the service configuration that should be used to
process the request. Must not be empty. Set this field to 'latest' to specify
using the latest configuration.
Corresponds to the JSON property serviceConfigId
539 540 541 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 539 def service_config_id @service_config_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
546 547 548 549 550 551 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 546 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @flags = args[:flags] if args.key?(:flags) @resources = args[:resources] if args.key?(:resources) @service_config_id = args[:service_config_id] if args.key?(:service_config_id) end |