Class: Google::Apis::ServicecontrolV2::CheckResponse
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV2::CheckResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb
Overview
Response message for the Check method.
Instance Attribute Summary collapse
-
#dynamic_metadata ⇒ Hash<String,Object>
Optional response metadata that will be emitted as dynamic metadata to be consumed by the caller of ServiceController.
-
#headers ⇒ Hash<String,String>
Returns a set of request contexts generated from the
CheckRequest. -
#status ⇒ Google::Apis::ServicecontrolV2::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckResponse
constructor
A new instance of CheckResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckResponse
Returns a new instance of CheckResponse.
580 581 582 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 580 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dynamic_metadata ⇒ Hash<String,Object>
Optional response metadata that will be emitted as dynamic metadata to be
consumed by the caller of ServiceController. For compatibility with the
ext_authz interface.
Corresponds to the JSON property dynamicMetadata
563 564 565 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 563 def @dynamic_metadata end |
#headers ⇒ Hash<String,String>
Returns a set of request contexts generated from the CheckRequest.
Corresponds to the JSON property headers
568 569 570 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 568 def headers @headers end |
#status ⇒ Google::Apis::ServicecontrolV2::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
578 579 580 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 578 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
585 586 587 588 589 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 585 def update!(**args) @dynamic_metadata = args[:dynamic_metadata] if args.key?(:dynamic_metadata) @headers = args[:headers] if args.key?(:headers) @status = args[:status] if args.key?(:status) end |