Class: Google::Apis::ServicecontrolV2::Oauth

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb

Overview

This message defines attributes associated with OAuth credentials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Oauth

Returns a new instance of Oauth.



648
649
650
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 648

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

The optional OAuth client ID. This is the unique public identifier issued by an authorization server to a registered client application. Empty string is equivalent to no oauth client id. WARNING: This is for MCP tools/call and tools/list authorization and not for general use. Corresponds to the JSON property clientId

Returns:

  • (String)


646
647
648
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 646

def client_id
  @client_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



653
654
655
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 653

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
end