Class: Google::Apis::ServicecontrolV2::ReportRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV2::ReportRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb
Overview
Request message for the Report method.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::ServicecontrolV2::AttributeContext>
Describes the list of operations to be reported.
-
#service_config_id ⇒ String
Specifies the version of the service configuration that should be used to process the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportRequest
constructor
A new instance of ReportRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportRequest
Returns a new instance of ReportRequest.
802 803 804 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 802 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::ServicecontrolV2::AttributeContext>
Describes the list of operations to be reported. Each operation is represented
as an AttributeContext, and contains all attributes around an API access.
Corresponds to the JSON property operations
793 794 795 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 793 def operations @operations end |
#service_config_id ⇒ String
Specifies the version of the service configuration that should be used to
process the request. Must not be empty. Set this field to 'latest' to specify
using the latest configuration.
Corresponds to the JSON property serviceConfigId
800 801 802 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 800 def service_config_id @service_config_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
807 808 809 810 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 807 def update!(**args) @operations = args[:operations] if args.key?(:operations) @service_config_id = args[:service_config_id] if args.key?(:service_config_id) end |