Class: Google::Apis::ServicecontrolV2::Request
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV2::Request
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb
Overview
This message defines attributes for an HTTP request. If the actual request is not an HTTP request, the runtime system should try to map the actual request to an equivalent HTTP request.
Instance Attribute Summary collapse
-
#auth ⇒ Google::Apis::ServicecontrolV2::Auth
This message defines request authentication attributes.
-
#headers ⇒ Hash<String,String>
The HTTP request headers.
-
#host ⇒ String
The HTTP request
Hostheader value. -
#id ⇒ String
The unique ID for a request, which can be propagated to downstream systems.
-
#method_prop ⇒ String
The HTTP request method, such as
GET,POST. -
#origin ⇒ String
The values from Origin header from the HTTP request, such as "https://console.
-
#path ⇒ String
The HTTP URL path, excluding the query parameters.
-
#protocol ⇒ String
The network protocol used with the request, such as "http/1.1", "spdy/3", "h2", "h2c", "webrtc", "tcp", "udp", "quic".
-
#query ⇒ String
The HTTP URL query in the format of
name1=value1&name2=value2, as it appears in the first line of the HTTP request. -
#reason ⇒ String
A special parameter for request reason.
-
#scheme ⇒ String
The HTTP URL scheme, such as
httpandhttps. -
#size ⇒ Fixnum
The HTTP request size in bytes.
-
#time ⇒ String
The timestamp when the
destinationservice receives the last byte of the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Request
constructor
A new instance of Request.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Request
Returns a new instance of Request.
1014 1015 1016 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth ⇒ Google::Apis::ServicecontrolV2::Auth
This message defines request authentication attributes. Terminology is based
on the JSON Web Token (JWT) standard, but the terms also correlate to concepts
in other standards.
Corresponds to the JSON property auth
940 941 942 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 940 def auth @auth end |
#headers ⇒ Hash<String,String>
The HTTP request headers. If multiple headers share the same key, they must be
merged according to the HTTP spec. All header keys must be lowercased, because
HTTP header keys are case-insensitive.
Corresponds to the JSON property headers
947 948 949 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 947 def headers @headers end |
#host ⇒ String
The HTTP request Host header value.
Corresponds to the JSON property host
952 953 954 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 952 def host @host end |
#id ⇒ String
The unique ID for a request, which can be propagated to downstream systems.
The ID should have low probability of collision within a single day for a
specific service.
Corresponds to the JSON property id
959 960 961 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 959 def id @id end |
#method_prop ⇒ String
The HTTP request method, such as GET, POST.
Corresponds to the JSON property method
964 965 966 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 964 def method_prop @method_prop end |
#origin ⇒ String
The values from Origin header from the HTTP request, such as "https://console.
cloud.google.com". Modern browsers can only have one origin. Special browsers
and/or HTTP clients may require multiple origins.
Corresponds to the JSON property origin
971 972 973 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 971 def origin @origin end |
#path ⇒ String
The HTTP URL path, excluding the query parameters.
Corresponds to the JSON property path
976 977 978 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 976 def path @path end |
#protocol ⇒ String
The network protocol used with the request, such as "http/1.1", "spdy/3", "h2",
"h2c", "webrtc", "tcp", "udp", "quic". See https://www.iana.org/assignments/
tls-extensiontype-values/tls-extensiontype-values.xhtml#alpn-protocol-ids for
details.
Corresponds to the JSON property protocol
984 985 986 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 984 def protocol @protocol end |
#query ⇒ String
The HTTP URL query in the format of name1=value1&name2=value2, as it appears
in the first line of the HTTP request. No decoding is performed.
Corresponds to the JSON property query
990 991 992 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 990 def query @query end |
#reason ⇒ String
A special parameter for request reason. It is used by security systems to
associate auditing information with a request.
Corresponds to the JSON property reason
996 997 998 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 996 def reason @reason end |
#scheme ⇒ String
The HTTP URL scheme, such as http and https.
Corresponds to the JSON property scheme
1001 1002 1003 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1001 def scheme @scheme end |
#size ⇒ Fixnum
The HTTP request size in bytes. If unknown, it must be -1.
Corresponds to the JSON property size
1006 1007 1008 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1006 def size @size end |
#time ⇒ String
The timestamp when the destination service receives the last byte of the
request.
Corresponds to the JSON property time
1012 1013 1014 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1012 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1019 def update!(**args) @auth = args[:auth] if args.key?(:auth) @headers = args[:headers] if args.key?(:headers) @host = args[:host] if args.key?(:host) @id = args[:id] if args.key?(:id) @method_prop = args[:method_prop] if args.key?(:method_prop) @origin = args[:origin] if args.key?(:origin) @path = args[:path] if args.key?(:path) @protocol = args[:protocol] if args.key?(:protocol) @query = args[:query] if args.key?(:query) @reason = args[:reason] if args.key?(:reason) @scheme = args[:scheme] if args.key?(:scheme) @size = args[:size] if args.key?(:size) @time = args[:time] if args.key?(:time) end |