Class: Google::Apis::ServicecontrolV2::Request
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV2::Request
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb
Overview
This message defines attributes for an HTTP request. If the actual request is not an HTTP request, the runtime system should try to map the actual request to an equivalent HTTP request.
Instance Attribute Summary collapse
-
#auth ⇒ Google::Apis::ServicecontrolV2::Auth
This message defines request authentication attributes.
-
#headers ⇒ Hash<String,String>
The HTTP request headers.
-
#host ⇒ String
The HTTP request
Hostheader value. -
#id ⇒ String
The unique ID for a request, which can be propagated to downstream systems.
-
#method_prop ⇒ String
The HTTP request method, such as
GET,POST. -
#origin ⇒ String
The values from Origin header from the HTTP request, such as "https://console.
-
#path ⇒ String
The HTTP URL path, excluding the query parameters.
-
#protocol ⇒ String
The network protocol used with the request, such as "http/1.1", "spdy/3", "h2", "h2c", "webrtc", "tcp", "udp", "quic".
-
#query ⇒ String
The HTTP URL query in the format of
name1=value1&name2=value2, as it appears in the first line of the HTTP request. -
#reason ⇒ String
A special parameter for request reason.
-
#scheme ⇒ String
The HTTP URL scheme, such as
httpandhttps. -
#size ⇒ Fixnum
The HTTP request size in bytes.
-
#time ⇒ String
The timestamp when the
destinationservice receives the last byte of the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Request
constructor
A new instance of Request.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Request
Returns a new instance of Request.
918 919 920 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 918 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth ⇒ Google::Apis::ServicecontrolV2::Auth
This message defines request authentication attributes. Terminology is based
on the JSON Web Token (JWT) standard, but the terms also correlate to concepts
in other standards.
Corresponds to the JSON property auth
844 845 846 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 844 def auth @auth end |
#headers ⇒ Hash<String,String>
The HTTP request headers. If multiple headers share the same key, they must be
merged according to the HTTP spec. All header keys must be lowercased, because
HTTP header keys are case-insensitive.
Corresponds to the JSON property headers
851 852 853 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 851 def headers @headers end |
#host ⇒ String
The HTTP request Host header value.
Corresponds to the JSON property host
856 857 858 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 856 def host @host end |
#id ⇒ String
The unique ID for a request, which can be propagated to downstream systems.
The ID should have low probability of collision within a single day for a
specific service.
Corresponds to the JSON property id
863 864 865 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 863 def id @id end |
#method_prop ⇒ String
The HTTP request method, such as GET, POST.
Corresponds to the JSON property method
868 869 870 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 868 def method_prop @method_prop end |
#origin ⇒ String
The values from Origin header from the HTTP request, such as "https://console.
cloud.google.com". Modern browsers can only have one origin. Special browsers
and/or HTTP clients may require multiple origins.
Corresponds to the JSON property origin
875 876 877 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 875 def origin @origin end |
#path ⇒ String
The HTTP URL path, excluding the query parameters.
Corresponds to the JSON property path
880 881 882 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 880 def path @path end |
#protocol ⇒ String
The network protocol used with the request, such as "http/1.1", "spdy/3", "h2",
"h2c", "webrtc", "tcp", "udp", "quic". See https://www.iana.org/assignments/
tls-extensiontype-values/tls-extensiontype-values.xhtml#alpn-protocol-ids for
details.
Corresponds to the JSON property protocol
888 889 890 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 888 def protocol @protocol end |
#query ⇒ String
The HTTP URL query in the format of name1=value1&name2=value2, as it appears
in the first line of the HTTP request. No decoding is performed.
Corresponds to the JSON property query
894 895 896 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 894 def query @query end |
#reason ⇒ String
A special parameter for request reason. It is used by security systems to
associate auditing information with a request.
Corresponds to the JSON property reason
900 901 902 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 900 def reason @reason end |
#scheme ⇒ String
The HTTP URL scheme, such as http and https.
Corresponds to the JSON property scheme
905 906 907 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 905 def scheme @scheme end |
#size ⇒ Fixnum
The HTTP request size in bytes. If unknown, it must be -1.
Corresponds to the JSON property size
910 911 912 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 910 def size @size end |
#time ⇒ String
The timestamp when the destination service receives the last byte of the
request.
Corresponds to the JSON property time
916 917 918 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 916 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 923 def update!(**args) @auth = args[:auth] if args.key?(:auth) @headers = args[:headers] if args.key?(:headers) @host = args[:host] if args.key?(:host) @id = args[:id] if args.key?(:id) @method_prop = args[:method_prop] if args.key?(:method_prop) @origin = args[:origin] if args.key?(:origin) @path = args[:path] if args.key?(:path) @protocol = args[:protocol] if args.key?(:protocol) @query = args[:query] if args.key?(:query) @reason = args[:reason] if args.key?(:reason) @scheme = args[:scheme] if args.key?(:scheme) @size = args[:size] if args.key?(:size) @time = args[:time] if args.key?(:time) end |