Class: Google::Apis::ServicecontrolV2::Resource
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV2::Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb
Overview
This message defines core attributes for a resource. A resource is an addressable (named) entity provided by the destination service. For example, a file stored on a network storage service.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Mutable.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
The labels or tags on the resource, such as AWS resource tags and Kubernetes resource labels.
-
#location ⇒ String
Immutable.
-
#name ⇒ String
The stable identifier (name) of a resource on the
service. -
#service ⇒ String
The name of the service that this resource belongs to, such as `pubsub.
-
#type ⇒ String
The type of the resource.
-
#uid ⇒ String
The unique identifier of the resource.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Resource
constructor
A new instance of Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Resource
Returns a new instance of Resource.
1087 1088 1089 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Annotations is an unstructured key-value map stored with a resource that may
be set by external tools to store and retrieve arbitrary metadata. They are
not queryable and should be preserved when modifying objects. More info: https:
//kubernetes.io/docs/concepts/overview/working-with-objects/annotations/
Corresponds to the JSON property annotations
1002 1003 1004 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1002 def annotations @annotations end |
#create_time ⇒ String
Output only. The timestamp when the resource was created. This may be either
the time creation was initiated or when it was completed.
Corresponds to the JSON property createTime
1008 1009 1010 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1008 def create_time @create_time end |
#delete_time ⇒ String
Output only. The timestamp when the resource was deleted. If the resource is
not deleted, this must be empty.
Corresponds to the JSON property deleteTime
1014 1015 1016 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1014 def delete_time @delete_time end |
#display_name ⇒ String
Mutable. The display name set by clients. Must be <= 63 characters.
Corresponds to the JSON property displayName
1019 1020 1021 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1019 def display_name @display_name end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
1026 1027 1028 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1026 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels or tags on the resource, such as AWS resource tags and Kubernetes
resource labels.
Corresponds to the JSON property labels
1032 1033 1034 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1032 def labels @labels end |
#location ⇒ String
Immutable. The location of the resource. The location encoding is specific to
the service provider, and new encoding may be introduced as the service
evolves. For Google Cloud products, the encoding is what is used by Google
Cloud APIs, such as us-east1, aws-us-east-1, and azure-eastus2. The
semantics of location is identical to the cloud.googleapis.com/location
label used by some Google Cloud APIs.
Corresponds to the JSON property location
1042 1043 1044 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1042 def location @location end |
#name ⇒ String
The stable identifier (name) of a resource on the service. A resource can be
logically identified as "//resource.service/resource.name". The
differences between a resource name and a URI are: * Resource name is a
logical identifier, independent of network protocol and API version. For
example, //pubsub.googleapis.com/projects/123/topics/news-feed. * URI often
includes protocol and version information, so it can be used directly by
applications. For example, https://pubsub.googleapis.com/v1/projects/123/
topics/news-feed. See https://cloud.google.com/apis/design/resource_names for
details.
Corresponds to the JSON property name
1055 1056 1057 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1055 def name @name end |
#service ⇒ String
The name of the service that this resource belongs to, such as pubsub.
googleapis.com. The service may be different from the DNS hostname that
actually serves the request.
Corresponds to the JSON property service
1062 1063 1064 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1062 def service @service end |
#type ⇒ String
The type of the resource. The syntax is platform-specific because different
platforms define their resources differently. For Google APIs, the type format
must be "service/kind", such as "pubsub.googleapis.com/Topic".
Corresponds to the JSON property type
1069 1070 1071 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1069 def type @type end |
#uid ⇒ String
The unique identifier of the resource. UID is unique in the time and space for
this resource within the scope of the service. It is typically generated by
the server on successful creation of a resource and must not be changed. UID
is used to uniquely identify resources with resource name reuses. This should
be a UUID4.
Corresponds to the JSON property uid
1078 1079 1080 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1078 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
1085 1086 1087 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1085 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1092 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @service = args[:service] if args.key?(:service) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |