Class: Google::Apis::ServicecontrolV2::ResourceInfo
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV2::ResourceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb
Overview
Describes a resource referenced in the request.
Instance Attribute Summary collapse
-
#container ⇒ String
Optional.
-
#location ⇒ String
Optional.
-
#name ⇒ String
The name of the resource referenced in the request.
-
#permission ⇒ String
The resource permission needed for this request.
-
#type ⇒ String
The resource type in the format of "
service/kind".
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceInfo
constructor
A new instance of ResourceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceInfo
Returns a new instance of ResourceInfo.
1143 1144 1145 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container ⇒ String
Optional. The identifier of the container of this resource. For Google Cloud
APIs, the resource container must be one of the following formats: - projects/
- folders/ - organizations/ Required for the policy enforcement on the
container level (e.g. VPCSC, Location Policy check, Org Policy check).
Corresponds to the JSON property container
1118 1119 1120 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1118 def container @container end |
#location ⇒ String
Optional. The location of the resource, it must be a valid zone, region or
multiregion, for example: "europe-west4", "northamerica-northeast1-a".
Required for location policy check.
Corresponds to the JSON property location
1125 1126 1127 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1125 def location @location end |
#name ⇒ String
The name of the resource referenced in the request.
Corresponds to the JSON property name
1130 1131 1132 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1130 def name @name end |
#permission ⇒ String
The resource permission needed for this request. The format must be "service/
plural.verb".
Corresponds to the JSON property permission
1136 1137 1138 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1136 def @permission end |
#type ⇒ String
The resource type in the format of "service/kind".
Corresponds to the JSON property type
1141 1142 1143 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1141 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1148 1149 1150 1151 1152 1153 1154 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1148 def update!(**args) @container = args[:container] if args.key?(:container) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @permission = args[:permission] if args.key?(:permission) @type = args[:type] if args.key?(:type) end |