Class: Google::Apis::ServicecontrolV2::Response

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb

Overview

This message defines attributes for a typical network response. It generally models semantics of an HTTP response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Response

Returns a new instance of Response.



1241
1242
1243
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1241

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_latencyString

The amount of time it takes the backend service to fully respond to a request. Measured from when the destination service starts to send the request to the backend until when the destination service receives the complete response from the backend. Corresponds to the JSON property backendLatency

Returns:

  • (String)


1216
1217
1218
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1216

def backend_latency
  @backend_latency
end

#codeFixnum

The HTTP response status code, such as 200 and 404. Corresponds to the JSON property code

Returns:

  • (Fixnum)


1221
1222
1223
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1221

def code
  @code
end

#headersHash<String,String>

The HTTP response headers. If multiple headers share the same key, they must be merged according to HTTP spec. All header keys must be lowercased, because HTTP header keys are case-insensitive. Corresponds to the JSON property headers

Returns:

  • (Hash<String,String>)


1228
1229
1230
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1228

def headers
  @headers
end

#sizeFixnum

The HTTP response size in bytes. If unknown, it must be -1. Corresponds to the JSON property size

Returns:

  • (Fixnum)


1233
1234
1235
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1233

def size
  @size
end

#timeString

The timestamp when the destination service sends the last byte of the response. Corresponds to the JSON property time

Returns:

  • (String)


1239
1240
1241
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1239

def time
  @time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1246
1247
1248
1249
1250
1251
1252
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1246

def update!(**args)
  @backend_latency = args[:backend_latency] if args.key?(:backend_latency)
  @code = args[:code] if args.key?(:code)
  @headers = args[:headers] if args.key?(:headers)
  @size = args[:size] if args.key?(:size)
  @time = args[:time] if args.key?(:time)
end