Class: Google::Apis::ServicecontrolV2::Response
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV2::Response
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb
Overview
This message defines attributes for a typical network response. It generally models semantics of an HTTP response.
Instance Attribute Summary collapse
-
#backend_latency ⇒ String
The amount of time it takes the backend service to fully respond to a request.
-
#code ⇒ Fixnum
The HTTP response status code, such as
200and404. -
#headers ⇒ Hash<String,String>
The HTTP response headers.
-
#size ⇒ Fixnum
The HTTP response size in bytes.
-
#time ⇒ String
The timestamp when the
destinationservice sends the last byte of the response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Response
constructor
A new instance of Response.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Response
Returns a new instance of Response.
1233 1234 1235 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1233 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_latency ⇒ String
The amount of time it takes the backend service to fully respond to a request.
Measured from when the destination service starts to send the request to the
backend until when the destination service receives the complete response from
the backend.
Corresponds to the JSON property backendLatency
1208 1209 1210 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1208 def backend_latency @backend_latency end |
#code ⇒ Fixnum
The HTTP response status code, such as 200 and 404.
Corresponds to the JSON property code
1213 1214 1215 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1213 def code @code end |
#headers ⇒ Hash<String,String>
The HTTP response headers. If multiple headers share the same key, they must
be merged according to HTTP spec. All header keys must be lowercased, because
HTTP header keys are case-insensitive.
Corresponds to the JSON property headers
1220 1221 1222 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1220 def headers @headers end |
#size ⇒ Fixnum
The HTTP response size in bytes. If unknown, it must be -1.
Corresponds to the JSON property size
1225 1226 1227 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1225 def size @size end |
#time ⇒ String
The timestamp when the destination service sends the last byte of the
response.
Corresponds to the JSON property time
1231 1232 1233 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1231 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1238 1239 1240 1241 1242 1243 1244 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1238 def update!(**args) @backend_latency = args[:backend_latency] if args.key?(:backend_latency) @code = args[:code] if args.key?(:code) @headers = args[:headers] if args.key?(:headers) @size = args[:size] if args.key?(:size) @time = args[:time] if args.key?(:time) end |