Class: Google::Apis::ServicecontrolV2::Response
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV2::Response
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb
Overview
This message defines attributes for a typical network response. It generally models semantics of an HTTP response.
Instance Attribute Summary collapse
-
#backend_latency ⇒ String
The amount of time it takes the backend service to fully respond to a request.
-
#code ⇒ Fixnum
The HTTP response status code, such as
200and404. -
#headers ⇒ Hash<String,String>
The HTTP response headers.
-
#size ⇒ Fixnum
The HTTP response size in bytes.
-
#time ⇒ String
The timestamp when the
destinationservice sends the last byte of the response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Response
constructor
A new instance of Response.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Response
Returns a new instance of Response.
1224 1225 1226 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_latency ⇒ String
The amount of time it takes the backend service to fully respond to a request.
Measured from when the destination service starts to send the request to the
backend until when the destination service receives the complete response from
the backend.
Corresponds to the JSON property backendLatency
1199 1200 1201 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1199 def backend_latency @backend_latency end |
#code ⇒ Fixnum
The HTTP response status code, such as 200 and 404.
Corresponds to the JSON property code
1204 1205 1206 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1204 def code @code end |
#headers ⇒ Hash<String,String>
The HTTP response headers. If multiple headers share the same key, they must
be merged according to HTTP spec. All header keys must be lowercased, because
HTTP header keys are case-insensitive.
Corresponds to the JSON property headers
1211 1212 1213 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1211 def headers @headers end |
#size ⇒ Fixnum
The HTTP response size in bytes. If unknown, it must be -1.
Corresponds to the JSON property size
1216 1217 1218 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1216 def size @size end |
#time ⇒ String
The timestamp when the destination service sends the last byte of the
response.
Corresponds to the JSON property time
1222 1223 1224 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1222 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1229 1230 1231 1232 1233 1234 1235 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1229 def update!(**args) @backend_latency = args[:backend_latency] if args.key?(:backend_latency) @code = args[:code] if args.key?(:code) @headers = args[:headers] if args.key?(:headers) @size = args[:size] if args.key?(:size) @time = args[:time] if args.key?(:time) end |