Class: Google::Apis::ServicecontrolV2::ServiceDelegationHistory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb

Overview

The history of delegation across multiple services as the result of the original user's action. Such as "service A uses its own account to do something for user B". This differs from ServiceAccountDelegationInfo, which only tracks the history of direct token exchanges (impersonation).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceDelegationHistory

Returns a new instance of ServiceDelegationHistory.



1300
1301
1302
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1300

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#original_principalString

The original end user who initiated the request to GCP. Corresponds to the JSON property originalPrincipal

Returns:

  • (String)


1292
1293
1294
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1292

def original_principal
  @original_principal
end

#service_metadataArray<Google::Apis::ServicecontrolV2::ServiceMetadata>

Data identifying the service specific jobs or units of work that were involved in a chain of service calls. Corresponds to the JSON property serviceMetadata



1298
1299
1300
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1298

def 
  @service_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1305
1306
1307
1308
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1305

def update!(**args)
  @original_principal = args[:original_principal] if args.key?(:original_principal)
  @service_metadata = args[:service_metadata] if args.key?(:service_metadata)
end