Class: Google::Apis::ServicecontrolV2::V2LogEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb

Overview

An individual log entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V2LogEntry

Returns a new instance of V2LogEntry.



1628
1629
1630
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#http_requestGoogle::Apis::ServicecontrolV2::V2HttpRequest

A common proto for logging HTTP requests. Only contains semantics defined by the HTTP specification. Product-specific logging information MUST be defined in a separate message. Corresponds to the JSON property httpRequest



1554
1555
1556
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1554

def http_request
  @http_request
end

#insert_idString

A unique ID for the log entry used for deduplication. If omitted, the implementation will generate one based on operation_id. Corresponds to the JSON property insertId

Returns:

  • (String)


1560
1561
1562
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1560

def insert_id
  @insert_id
end

#labelsHash<String,String>

A set of user-defined (key, value) data that provides additional information about the log entry. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1566
1567
1568
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1566

def labels
  @labels
end

#monitored_resource_labelsHash<String,String>

A set of user-defined (key, value) data that provides additional information about the moniotored resource that the log entry belongs to. Corresponds to the JSON property monitoredResourceLabels

Returns:

  • (Hash<String,String>)


1572
1573
1574
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1572

def monitored_resource_labels
  @monitored_resource_labels
end

#nameString

Required. The log to which this log entry belongs. Examples: "syslog", " book_log". Corresponds to the JSON property name

Returns:

  • (String)


1578
1579
1580
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1578

def name
  @name
end

#operationGoogle::Apis::ServicecontrolV2::V2LogEntryOperation

Additional information about a potentially long-running operation with which a log entry is associated. Corresponds to the JSON property operation



1584
1585
1586
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1584

def operation
  @operation
end

#proto_payloadHash<String,Object>

The log entry payload, represented as a protocol buffer that is expressed as a JSON object. The only accepted type currently is AuditLog. Corresponds to the JSON property protoPayload

Returns:

  • (Hash<String,Object>)


1590
1591
1592
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1590

def proto_payload
  @proto_payload
end

#severityString

The severity of the log entry. The default value is LogSeverity.DEFAULT. Corresponds to the JSON property severity

Returns:

  • (String)


1595
1596
1597
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1595

def severity
  @severity
end

#source_locationGoogle::Apis::ServicecontrolV2::V2LogEntrySourceLocation

Additional information about the source code location that produced the log entry. Corresponds to the JSON property sourceLocation



1601
1602
1603
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1601

def source_location
  @source_location
end

#struct_payloadHash<String,Object>

The log entry payload, represented as a structure that is expressed as a JSON object. Corresponds to the JSON property structPayload

Returns:

  • (Hash<String,Object>)


1607
1608
1609
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1607

def struct_payload
  @struct_payload
end

#text_payloadString

The log entry payload, represented as a Unicode string (UTF-8). Corresponds to the JSON property textPayload

Returns:

  • (String)


1612
1613
1614
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1612

def text_payload
  @text_payload
end

#timestampString

The time the event described by the log entry occurred. If omitted, defaults to operation start time. Corresponds to the JSON property timestamp

Returns:

  • (String)


1618
1619
1620
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1618

def timestamp
  @timestamp
end

#traceString

Optional. Resource name of the trace associated with the log entry, if any. If this field contains a relative resource name, you can assume the name is relative to //tracing.googleapis.com. Example: projects/my-projectid/traces/ 06796866738c859f2f19b7cfb3214824 Corresponds to the JSON property trace

Returns:

  • (String)


1626
1627
1628
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1626

def trace
  @trace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1633

def update!(**args)
  @http_request = args[:http_request] if args.key?(:http_request)
  @insert_id = args[:insert_id] if args.key?(:insert_id)
  @labels = args[:labels] if args.key?(:labels)
  @monitored_resource_labels = args[:monitored_resource_labels] if args.key?(:monitored_resource_labels)
  @name = args[:name] if args.key?(:name)
  @operation = args[:operation] if args.key?(:operation)
  @proto_payload = args[:proto_payload] if args.key?(:proto_payload)
  @severity = args[:severity] if args.key?(:severity)
  @source_location = args[:source_location] if args.key?(:source_location)
  @struct_payload = args[:struct_payload] if args.key?(:struct_payload)
  @text_payload = args[:text_payload] if args.key?(:text_payload)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
  @trace = args[:trace] if args.key?(:trace)
end