Class: Google::Apis::ServicecontrolV2::V2LogEntrySourceLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb

Overview

Additional information about the source code location that produced the log entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V2LogEntrySourceLocation

Returns a new instance of V2LogEntrySourceLocation.



1719
1720
1721
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fileString

Optional. Source file name. Depending on the runtime environment, this might be a simple name or a fully-qualified name. Corresponds to the JSON property file

Returns:

  • (String)


1702
1703
1704
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1702

def file
  @file
end

#functionString

Optional. Human-readable name of the function or method being invoked, with optional context such as the class or package name. This information may be used in contexts such as the logs viewer, where a file and line number are less meaningful. The format can vary by language. For example: qual.if.ied. Class.method (Java), dir/package.func (Go), function (Python). Corresponds to the JSON property function

Returns:

  • (String)


1711
1712
1713
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1711

def function
  @function
end

#lineFixnum

Optional. Line within the source file. 1-based; 0 indicates no line number available. Corresponds to the JSON property line

Returns:

  • (Fixnum)


1717
1718
1719
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1717

def line
  @line
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1724
1725
1726
1727
1728
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1724

def update!(**args)
  @file = args[:file] if args.key?(:file)
  @function = args[:function] if args.key?(:function)
  @line = args[:line] if args.key?(:line)
end