Class: Google::Apis::ServicecontrolV2::V2ResourceEvent
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV2::V2ResourceEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb
Overview
Report v2 extension proto for passing the resource metadata associated with a resource create/update/delete/undelete event from ESF to Chemist. ResourceEvent proto should be serialized into the ReportRequest.operations. extensions.
Instance Attribute Summary collapse
-
#context_id ⇒ Fixnum
The ESF unique context id of the api request, from which this resource event originated.
-
#destinations ⇒ String
The destinations field determines which backend services should handle the event.
-
#parent ⇒ Google::Apis::ServicecontrolV2::Resource
This message defines core attributes for a resource.
-
#path ⇒ String
The api path the resource event was created in.
-
#payload ⇒ Hash<String,Object>
The payload contains metadata associated with the resource event.
-
#resource ⇒ Google::Apis::ServicecontrolV2::Resource
This message defines core attributes for a resource.
-
#type ⇒ String
The resource event type determines how the backend service should process the event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V2ResourceEvent
constructor
A new instance of V2ResourceEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V2ResourceEvent
Returns a new instance of V2ResourceEvent.
1794 1795 1796 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1794 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_id ⇒ Fixnum
The ESF unique context id of the api request, from which this resource event
originated. This field is only needed for CAIS integration via api annotation.
See go/cais-lro-delete for more details.
Corresponds to the JSON property contextId
1752 1753 1754 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1752 def context_id @context_id end |
#destinations ⇒ String
The destinations field determines which backend services should handle the
event. This should be specified as a comma-delimited string.
Corresponds to the JSON property destinations
1758 1759 1760 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1758 def destinations @destinations end |
#parent ⇒ Google::Apis::ServicecontrolV2::Resource
This message defines core attributes for a resource. A resource is an
addressable (named) entity provided by the destination service. For example, a
file stored on a network storage service.
Corresponds to the JSON property parent
1765 1766 1767 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1765 def parent @parent end |
#path ⇒ String
The api path the resource event was created in. This should match the source
of the payload field. For direct integrations with Chemist, this should
generally be the RESPONSE. go/resource-event-pipeline-type
Corresponds to the JSON property path
1772 1773 1774 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1772 def path @path end |
#payload ⇒ Hash<String,Object>
The payload contains metadata associated with the resource event. A
ResourceEventPayloadStatus is provided instead if the original payload cannot
be returned due to a limitation (e.g. size limit).
Corresponds to the JSON property payload
1779 1780 1781 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1779 def payload @payload end |
#resource ⇒ Google::Apis::ServicecontrolV2::Resource
This message defines core attributes for a resource. A resource is an
addressable (named) entity provided by the destination service. For example, a
file stored on a network storage service.
Corresponds to the JSON property resource
1786 1787 1788 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1786 def resource @resource end |
#type ⇒ String
The resource event type determines how the backend service should process the
event.
Corresponds to the JSON property type
1792 1793 1794 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1792 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1799 def update!(**args) @context_id = args[:context_id] if args.key?(:context_id) @destinations = args[:destinations] if args.key?(:destinations) @parent = args[:parent] if args.key?(:parent) @path = args[:path] if args.key?(:path) @payload = args[:payload] if args.key?(:payload) @resource = args[:resource] if args.key?(:resource) @type = args[:type] if args.key?(:type) end |