Class: Google::Apis::ServicecontrolV2::V2ResourceEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb

Overview

Report v2 extension proto for passing the resource metadata associated with a resource create/update/delete/undelete event from ESF to Chemist. ResourceEvent proto should be serialized into the ReportRequest.operations. extensions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V2ResourceEvent

Returns a new instance of V2ResourceEvent.



1785
1786
1787
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1785

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#context_idFixnum

The ESF unique context id of the api request, from which this resource event originated. This field is only needed for CAIS integration via api annotation. See go/cais-lro-delete for more details. Corresponds to the JSON property contextId

Returns:

  • (Fixnum)


1743
1744
1745
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1743

def context_id
  @context_id
end

#destinationsString

The destinations field determines which backend services should handle the event. This should be specified as a comma-delimited string. Corresponds to the JSON property destinations

Returns:

  • (String)


1749
1750
1751
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1749

def destinations
  @destinations
end

#parentGoogle::Apis::ServicecontrolV2::Resource

This message defines core attributes for a resource. A resource is an addressable (named) entity provided by the destination service. For example, a file stored on a network storage service. Corresponds to the JSON property parent



1756
1757
1758
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1756

def parent
  @parent
end

#pathString

The api path the resource event was created in. This should match the source of the payload field. For direct integrations with Chemist, this should generally be the RESPONSE. go/resource-event-pipeline-type Corresponds to the JSON property path

Returns:

  • (String)


1763
1764
1765
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1763

def path
  @path
end

#payloadHash<String,Object>

The payload contains metadata associated with the resource event. A ResourceEventPayloadStatus is provided instead if the original payload cannot be returned due to a limitation (e.g. size limit). Corresponds to the JSON property payload

Returns:

  • (Hash<String,Object>)


1770
1771
1772
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1770

def payload
  @payload
end

#resourceGoogle::Apis::ServicecontrolV2::Resource

This message defines core attributes for a resource. A resource is an addressable (named) entity provided by the destination service. For example, a file stored on a network storage service. Corresponds to the JSON property resource



1777
1778
1779
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1777

def resource
  @resource
end

#typeString

The resource event type determines how the backend service should process the event. Corresponds to the JSON property type

Returns:

  • (String)


1783
1784
1785
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1783

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1790
1791
1792
1793
1794
1795
1796
1797
1798
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1790

def update!(**args)
  @context_id = args[:context_id] if args.key?(:context_id)
  @destinations = args[:destinations] if args.key?(:destinations)
  @parent = args[:parent] if args.key?(:parent)
  @path = args[:path] if args.key?(:path)
  @payload = args[:payload] if args.key?(:payload)
  @resource = args[:resource] if args.key?(:resource)
  @type = args[:type] if args.key?(:type)
end