Class: Google::Apis::ServicecontrolV2::ViolationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb

Overview

Provides information about the Policy violation info for this request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ViolationInfo

Returns a new instance of ViolationInfo.



1851
1852
1853
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checked_valueString

Optional. Value that is being checked for the policy. This could be in encrypted form (if pii sensitive). This field will only be emitted in LIST_POLICY types Corresponds to the JSON property checkedValue

Returns:

  • (String)


1827
1828
1829
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1827

def checked_value
  @checked_value
end

#constraintString

Optional. Constraint name Corresponds to the JSON property constraint

Returns:

  • (String)


1832
1833
1834
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1832

def constraint
  @constraint
end

#constraint_violation_infoHash<String,Object>

Optional. Provides extra information for the specific violated constraint. See the constraint's documentation to determine if this field is populated and what the structure of the message should be. Corresponds to the JSON property constraintViolationInfo

Returns:

  • (Hash<String,Object>)


1839
1840
1841
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1839

def constraint_violation_info
  @constraint_violation_info
end

#error_messageString

Optional. Error message that policy is indicating. Corresponds to the JSON property errorMessage

Returns:

  • (String)


1844
1845
1846
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1844

def error_message
  @error_message
end

#policy_typeString

Optional. Indicates the type of the policy. Corresponds to the JSON property policyType

Returns:

  • (String)


1849
1850
1851
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1849

def policy_type
  @policy_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1856
1857
1858
1859
1860
1861
1862
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1856

def update!(**args)
  @checked_value = args[:checked_value] if args.key?(:checked_value)
  @constraint = args[:constraint] if args.key?(:constraint)
  @constraint_violation_info = args[:constraint_violation_info] if args.key?(:constraint_violation_info)
  @error_message = args[:error_message] if args.key?(:error_message)
  @policy_type = args[:policy_type] if args.key?(:policy_type)
end