Class: Google::Apis::ServicecontrolV2::ViolationInfo
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV2::ViolationInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v2/classes.rb,
lib/google/apis/servicecontrol_v2/representations.rb,
lib/google/apis/servicecontrol_v2/representations.rb
Overview
Provides information about the Policy violation info for this request.
Instance Attribute Summary collapse
-
#checked_value ⇒ String
Optional.
-
#constraint ⇒ String
Optional.
-
#constraint_violation_info ⇒ Hash<String,Object>
Optional.
-
#error_message ⇒ String
Optional.
-
#policy_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ViolationInfo
constructor
A new instance of ViolationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ViolationInfo
Returns a new instance of ViolationInfo.
1834 1835 1836 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1834 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checked_value ⇒ String
Optional. Value that is being checked for the policy. This could be in
encrypted form (if pii sensitive). This field will only be emitted in
LIST_POLICY types
Corresponds to the JSON property checkedValue
1810 1811 1812 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1810 def checked_value @checked_value end |
#constraint ⇒ String
Optional. Constraint name
Corresponds to the JSON property constraint
1815 1816 1817 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1815 def constraint @constraint end |
#constraint_violation_info ⇒ Hash<String,Object>
Optional. Provides extra information for the specific violated constraint. See
the constraint's documentation to determine if this field is populated and
what the structure of the message should be.
Corresponds to the JSON property constraintViolationInfo
1822 1823 1824 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1822 def constraint_violation_info @constraint_violation_info end |
#error_message ⇒ String
Optional. Error message that policy is indicating.
Corresponds to the JSON property errorMessage
1827 1828 1829 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1827 def @error_message end |
#policy_type ⇒ String
Optional. Indicates the type of the policy.
Corresponds to the JSON property policyType
1832 1833 1834 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1832 def policy_type @policy_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1839 1840 1841 1842 1843 1844 1845 |
# File 'lib/google/apis/servicecontrol_v2/classes.rb', line 1839 def update!(**args) @checked_value = args[:checked_value] if args.key?(:checked_value) @constraint = args[:constraint] if args.key?(:constraint) @constraint_violation_info = args[:constraint_violation_info] if args.key?(:constraint_violation_info) @error_message = args[:error_message] if args.key?(:error_message) @policy_type = args[:policy_type] if args.key?(:policy_type) end |